@@ -1,4 +1,4 @@
 from .test_aws import TestAWSToolKit
-from .test_email import TestEmailToolKit
+from .test_email import TestSendGmailSimple
 from .test_slack import TestSlackToolKit
 from .test_snowflake import TestSnowflakeToolKit
\ No newline at end of file
